PublicKeyAuth

Struct PublicKeyAuth 

pub struct PublicKeyAuth { /* private fields */ }
Simple public key authentication against a static set of keys.

Stores public keys and validates against them.

Example

use wish::auth::PublicKeyAuth;
use wish::PublicKey;

let key = PublicKey::new("ssh-ed25519", key_data);
let auth = PublicKeyAuth::new().add_key(key);

Implementations

Source

impl PublicKeyAuth

pub fn new() -> Self

Creates a new empty public key auth handler.

pub fn add_key(self, key: PublicKey) -> Self

Adds a global key that can authenticate any user.

pub fn add_keys<I>(self, keys: I) -> Self
where I: IntoIterator<Item = PublicKey>,

Adds multiple global keys.

pub fn add_user_key(self, username: impl Into<String>, key: PublicKey) -> Self

Adds a key that can only authenticate a specific user.

pub fn global_key_count(&self) -> usize

Returns the number of global keys.

pub fn user_key_count(&self, username: &str) -> usize

Returns the number of keys for a specific user.