pub struct PublicKeyAuth { /* private fields */ }Expand description
Implementations
Sourceimpl PublicKeyAuth
impl PublicKeyAuth
Sourcepub fn add_keys<I>(self, keys: I) -> Selfwhere
I: IntoIterator<Item = PublicKey>,
pub fn add_keys<I>(self, keys: I) -> Selfwhere
I: IntoIterator<Item = PublicKey>,
Adds multiple global keys.
Sourcepub fn add_user_key(self, username: impl Into<String>, key: PublicKey) -> Self
pub fn add_user_key(self, username: impl Into<String>, key: PublicKey) -> Self
Adds a key that can only authenticate a specific user.
Sourcepub fn global_key_count(&self) -> usize
pub fn global_key_count(&self) -> usize
Returns the number of global keys.
Sourcepub fn user_key_count(&self, username: &str) -> usize
pub fn user_key_count(&self, username: &str) -> usize
Returns the number of keys for a specific user.